@@ -4,6 +4,10 @@ Identifies callable analysis regions surrounded by larger regions lacking
 aligned bases. This allows parallelization of smaller chromosome chunks
 through post-processing and variant calling, with each sub-section
 mapping handled separately.
+
+Regions are split to try to maintain relative uniformity across the
+genome and avoid extremes of large blocks or large numbers of
+small blocks.
 """
 import contextlib
 import os
@@ -15,7 +19,6 @@ from py_descriptive_statistics import Enum as Stats
 
 from bcbio import utils, broad
 from bcbio.log import logger
-from bcbio.distributed import messaging
 from bcbio.distributed.messaging import parallel_runner
 from bcbio.distributed.split import parallel_split_combine
 from bcbio.distributed.transaction import file_transaction
@@ -28,8 +31,8 @@ def parallel_callable_loci(in_bam, ref_file, config):
     runner = parallel_runner(parallel, {}, config)
     split_fn = shared.process_bam_by_chromosome("-callable.bed", "work_bam")
     out = parallel_split_combine([[data]], split_fn, runner,
-                                  "calc_callable_loci", "combine_bed",
-                                  "callable_bed", ["config"])[0]
+                                 "calc_callable_loci", "combine_bed",
+                                 "callable_bed", ["config"])[0]
     return out[0]["callable_bed"]
 
 def combine_bed(in_files, out_file, config):
@@ -74,7 +77,25 @@ def calc_callable_loci(data, region=None, out_file=None):
                         if tregion.chrom == region:
                             out_handle.write("%s\t%s\t%s\tNO_COVERAGE\n" %
                                              (tregion.chrom, tregion.start, tregion.stop))
-    return [{"callable_bed": out_file, "config": data["config"]}]
+    return [{"callable_bed": out_file, "config": data["config"], "work_bam": data["work_bam"]}]
+
+def sample_callable_bed(bam_file, ref_file, config):
+    """Retrieve callable regions for a sample subset by defined analysis regions.
+    """
+    out_file = "%s-callable_sample.bed" % os.path.splitext(bam_file)[0]
+    callable_bed = parallel_callable_loci(bam_file, ref_file, config)
+    input_regions_bed = config["algorithm"].get("variant_regions", None)
+    if not utils.file_uptodate(out_file, callable_bed):
+        with file_transaction(out_file) as tx_out_file:
+            callable_regions = pybedtools.BedTool(callable_bed)
+            filter_regions = callable_regions.filter(lambda x: x.name == "CALLABLE")
+            if input_regions_bed:
+                if not utils.file_uptodate(out_file, input_regions_bed):
+                    input_regions = pybedtools.BedTool(input_regions_bed)
+                    filter_regions.intersect(input_regions).saveas(tx_out_file)
+            else:
+                filter_regions.saveas(tx_out_file)
+    return out_file
 
 def get_ref_bedtool(ref_file, config):
     """Retrieve a pybedtool BedTool object with reference sizes from input reference.
@@ -135,25 +156,63 @@ def _add_config_regions(nblock_regions, ref_regions, config):
     else:
         return nblock_regions
 
+class NBlockRegionPicker:
+    """Choose nblock regions reasonably spaced across chromosomes.
+
+    This avoids excessively large blocks and also large numbers of tiny blocks
+    by splitting to a defined number of blocks.
+
+    Assumes to be iterating over an ordered input file and needs re-initiation
+    with each new file processed as it keeps track of previous blocks to
+    maintain the splitting.
+    """
+    def __init__(self, ref_regions, config):
+        self._chr_last_blocks = {}
+        target_blocks = int(config["algorithm"].get("nomap_split_targets", 2000))
+        self._target_size = self._get_target_size(target_blocks, ref_regions)
+
+    def _get_target_size(self, target_blocks, ref_regions):
+        size = 0
+        for x in ref_regions:
+            size += (x.end - x.start)
+        return size // target_blocks
+
+    def include_block(self, x):
+        """Check for inclusion of block based on distance from previous.
+        """
+        last_pos = self._chr_last_blocks.get(x.chrom, 0)
+        if (x.start - last_pos) > self._target_size:
+            self._chr_last_blocks[x.chrom] = x.stop
+            return True
+        else:
+            return False
+
 def block_regions(in_bam, ref_file, config):
     """Find blocks of regions for analysis from mapped input BAM file.
 
     Identifies islands of callable regions, surrounding by regions
     with no read support, that can be analyzed independently.
     """
-    min_n_size = int(config["algorithm"].get("nomap_split_size", 5000))
+    min_n_size = int(config["algorithm"].get("nomap_split_size", 100))
     callable_bed = parallel_callable_loci(in_bam, ref_file, config)
     block_bed = "%s-analysisblocks%s" % os.path.splitext(callable_bed)
+    callblock_bed = "%s-callableblocks%s" % os.path.splitext(callable_bed)
     if utils.file_uptodate(block_bed, callable_bed):
         ready_regions = pybedtools.BedTool(block_bed)
     else:
         ref_regions = get_ref_bedtool(ref_file, config)
         nblock_regions = _get_nblock_regions(callable_bed, min_n_size)
         nblock_regions = _add_config_regions(nblock_regions, ref_regions, config)
-        nblock_regions = nblock_regions.merge(d=min_n_size)
-        ready_regions = ref_regions.subtract(nblock_regions)
+        block_filter = NBlockRegionPicker(ref_regions, config)
+        nblock_size_filtered = nblock_regions.filter(block_filter.include_block).saveas()
+        if len(nblock_size_filtered) > len(ref_regions):
+            final_nblock_regions = nblock_size_filtered
+        else:
+            final_nblock_regions = nblock_regions
+        ready_regions = ref_regions.subtract(final_nblock_regions).merge(d=min_n_size)
         ready_regions.saveas(block_bed)
-    return [(r.chrom, int(r.start), int(r.stop)) for r in ready_regions]
+        ref_regions.subtract(nblock_regions).merge(d=min_n_size).saveas(callblock_bed)
+    return callblock_bed, [(r.chrom, int(r.start), int(r.stop)) for r in ready_regions]
 
 def _write_bed_regions(sample, final_regions):
     work_dir = sample["dirs"]["work"]
@@ -163,7 +222,7 @@ def _write_bed_regions(sample, final_regions):
     out_file_ref = os.path.join(work_dir, "noanalysis_blocks.bed")
     final_regions.saveas(out_file)
     noanalysis_regions.saveas(out_file_ref)
-    return out_file_ref
+    return out_file, out_file_ref
 
 def _analysis_block_stats(regions):
     """Provide statistics on sizes and number of analysis blocks.
@@ -203,17 +262,23 @@ def combine_sample_regions(samples):
     min_n_size = int(samples[0]["config"]["algorithm"].get("nomap_split_size", 5000))
     final_regions = None
     all_regions = []
-    for regions in (x["regions"] for x in samples):
+    for regions in (x["regions"] for x in samples if "regions" in x):
         bed_lines = ["%s\t%s\t%s" % (c, s, e) for (c, s, e) in regions]
         all_regions.append(pybedtools.BedTool("\n".join(bed_lines), from_string=True))
-    if len(all_regions) == 1:
+    if len(all_regions) == 0:
+        final_regions = []
+    elif len(all_regions) == 1:
         final_regions = all_regions[0]
     else:
         ref_bedtool = get_ref_bedtool(samples[0]["sam_ref"], samples[0]["config"])
         combo_regions = _combine_regions(all_regions, ref_bedtool)
         final_regions = combo_regions.merge(d=min_n_size)
-    _analysis_block_stats(final_regions)
-    no_analysis_file = _write_bed_regions(samples[0], final_regions)
+    if len(all_regions) > 0:
+        _analysis_block_stats(final_regions)
+        analysis_file, no_analysis_file = _write_bed_regions(samples[0], final_regions)
+    else:
+        analysis_file, no_analysis_file = None, None
     regions = {"analysis": [(r.chrom, int(r.start), int(r.stop)) for r in final_regions],
-               "noanalysis": no_analysis_file}
+               "noanalysis": no_analysis_file,
+               "analysis_bed": analysis_file}
     return regions
