@@ -16,10 +16,11 @@ from bcbio.pipeline.run_info import get_run_info
 from bcbio.pipeline.demultiplex import add_multiplex_across_lanes
 from bcbio.pipeline.merge import organize_samples
 from bcbio.pipeline import lane, region, qcsummary
+from bcbio.provenance import programs
 from bcbio.solexa.flowcell import get_fastq_dir
 from bcbio.variation.realign import parallel_realign_sample
 from bcbio.variation.genotype import parallel_variantcall, combine_multiple_callers
-from bcbio.variation import ensemble, recalibrate
+from bcbio.variation import ensemble, population, recalibrate, validate
 
 def run_main(config, config_file, work_dir, parallel,
          fc_dir=None, run_info_yaml=None):
@@ -47,11 +48,29 @@ def run_main(config, config_file, work_dir, parallel,
     lane_items = lane.process_all_lanes(lanes, run_parallel)
     pipelines = _pair_lanes_with_pipelines(lane_items)
     for pipeline, pipeline_items in pipelines.items():
+        pipeline_items = _add_provenance(pipeline_items, dirs, config)
         for xs in pipeline.run(config, config_file, run_parallel, dirs, pipeline_items):
             assert len(xs) == 1
             upload.from_sample(xs[0])
     qcsummary.write_metrics(run_info, fc_name, fc_date, dirs)
 
+def _add_provenance(items, dirs, config):
+    p = programs.write_versions(dirs, config)
+    out = []
+    for item_info in items:
+        item = item_info[2]
+        if item.get("upload"):
+            entity_id = "%s.%s.%s" % (item["upload"]["fc_date"],
+                                      item["upload"]["fc_name"],
+                                      item["description"])
+        else:
+            entity_id = item["description"]
+        item["provenance"] = {"programs": p, "entity": entity_id}
+        cur = list(item_info)
+        cur[2] = item
+        out.append(cur)
+    return out
+
 # ## Utility functions
 
 def parse_cl_args(in_args):
@@ -170,6 +189,7 @@ class Variant2Pipeline(AbstractPipeline):
         # Handle alignment and preparation requiring the entire input file
         samples = run_parallel("align_prep_full", (list(x) + [config_file] for x in lane_items))
         regions = callable.combine_sample_regions(samples)
+        samples = region.add_region_info(samples, regions)
         # Handle all variant calling on sub-regions of the input file
         samples = region.clean_sample_data(samples)
         samples = region.parallel_prep_region(samples, regions, run_parallel)
@@ -177,8 +197,10 @@ class Variant2Pipeline(AbstractPipeline):
         samples = run_parallel("postprocess_variants", samples)
         samples = combine_multiple_callers(samples)
         samples = ensemble.combine_calls_parallel(samples, run_parallel)
+        samples = population.prep_db_parallel(samples, run_parallel)
         samples = region.delayed_bamprep_merge(samples, run_parallel)
         samples = qcsummary.generate_parallel(samples, run_parallel)
+        samples = validate.summarize_grading(samples)
         return samples
 
 class SNPCallingPipeline(VariantPipeline):
