@@ -85,11 +85,11 @@ def _run_info_from_yaml(fc_dir, run_info_yaml):
             pass
     global_config = {}
     if isinstance(loaded, dict):
+        global_config = copy.deepcopy(loaded)
+        del global_config["details"]
         if loaded.has_key("fc_name") and loaded.has_key("fc_date"):
             fc_name = loaded["fc_name"].replace(" ", "_")
             fc_date = str(loaded["fc_date"]).replace(" ", "_")
-            global_config = copy.deepcopy(loaded)
-            del global_config["details"]
         loaded = loaded["details"]
     if fc_name is None:
         fc_name, fc_date = _unique_flowcell_info()
@@ -105,6 +105,11 @@ def _run_info_from_yaml(fc_dir, run_info_yaml):
         if not item.has_key("description"):
             item["description"] = str(item["lane"])
         item["description_filenames"] = global_config.get("description_filenames", False)
+        upload = global_config.get("upload")
+        if upload:
+            upload["fc_name"] = fc_name
+            upload["fc_date"] = fc_date
+        item["upload"] = upload
         run_details.append(item)
     run_info = dict(details=run_details, run_id="")
     return fc_name, fc_date, run_info
