@@ -103,7 +103,7 @@ def write_noanalysis_reads(in_file, region_file, out_file):
             subprocess.check_call(cl.format(**locals()), shell=True)
     return out_file
 
-def subset_bam_by_region(in_file, region, out_file_base = None):
+def subset_bam_by_region(in_file, region, out_file_base=None):
     """Subset BAM files based on specified chromosome region.
     """
     if out_file_base is not None:
@@ -124,28 +124,49 @@ def subset_bam_by_region(in_file, region, out_file_base = None):
                             out_bam.write(read)
     return out_file
 
+def _line_in_region(line, chrom, start, end):
+    """Check if the region defined by the BED line falls into chrom, start, end
+    """
+    if start is not None:
+        start = int(start)
+        end = int(end)
+    if line.startswith(chrom):
+        parts = line.split()
+        if parts[0] == chrom:
+            cur_start = int(parts[1])
+            cur_end = int(parts[2])
+            if (start is None or
+                    (cur_start >= start and cur_start <= end) or
+                    (cur_end >= start and cur_end <= end)):
+                return cur_start
+    return None
+
 def subset_variant_regions(variant_regions, region, out_file):
     """Return BED file subset by a specified chromosome region.
 
-    variant_regions is a BED file, region is a chromosome name.
+    variant_regions is a BED file, region is a chromosome name or tuple
+    of (name, start, end) for a genomic region.
     """
     if region is None:
         return variant_regions
     elif variant_regions is None:
         return region
-    elif isinstance(region, (list, tuple)):
-        return region
-    elif region.find(":") > 0:
+    elif not isinstance(region, (list, tuple)) and region.find(":") > 0:
         raise ValueError("Partial chromosome regions not supported")
     else:
+        if isinstance(region, (list, tuple)):
+            chrom, rstart, rend = region
+        else:
+            chrom = region
+            rstart, rend = None, None
         # create an ordered subset file for processing
         subset_file = "{0}-regions.bed".format(os.path.splitext(out_file)[0])
         items = []
         with open(variant_regions) as in_handle:
             for line in in_handle:
-                if line.startswith(region) and line.split()[0] == region:
-                    start = int(line.split()[1])
-                    items.append((start, line))
+                cur_start = _line_in_region(line, chrom, rstart, rend)
+                if cur_start is not None:
+                    items.append((cur_start, line))
         if len(items) > 0:
             if not os.path.exists(subset_file):
                 with open(subset_file, "w") as out_handle:
