@@ -13,14 +13,12 @@ import os
 import collections
 import copy
 import itertools
-import shutil
 
 from bcbio import broad
 from bcbio.log import logger
 from bcbio.utils import file_exists, safe_makedir
 from bcbio.distributed.transaction import file_transaction
-from bcbio.distributed.split import (parallel_split_combine,
-                                     grouped_parallel_split_combine)
+from bcbio.distributed.split import grouped_parallel_split_combine
 from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_ref_file,
                                    subset_variant_regions)
 from bcbio.variation.realign import has_aligned_reads
@@ -38,8 +36,6 @@ def _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp, region, out_file
     coverage_depth = config["algorithm"].get("coverage_depth", "high").lower()
     variant_regions = config["algorithm"].get("variant_regions", None)
     confidence = "4.0" if coverage_depth in ["low"] else "30.0"
-    if out_file is None:
-        out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     region = subset_variant_regions(variant_regions, region, out_file)
 
     params = ["-R", ref_file,
@@ -56,18 +52,20 @@ def _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp, region, out_file
         params += ["--dbsnp", dbsnp]
     if region:
         params += ["-L", bamprep.region_to_gatk(region), "--interval_set_rule", "INTERSECTION"]
-    return broad_runner, params, out_file
+    return broad_runner, params
 
 def unified_genotyper(align_bams, ref_file, config, dbsnp=None,
                        region=None, out_file=None):
     """Perform SNP genotyping on the given alignment file.
     """
-    broad_runner, params, out_file = \
-        _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
-                               region, out_file)
+    if out_file is None:
+        out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     if not file_exists(out_file):
+        broad_runner, params = \
+            _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
+                                   region, out_file)
         if (not isinstance(region, (list, tuple)) and
-            not all(has_aligned_reads(x, region) for x in align_bams)):
+                not all(has_aligned_reads(x, region) for x in align_bams)):
             write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
@@ -83,21 +81,55 @@ def haplotype_caller(align_bams, ref_file, config, dbsnp=None,
 
     This requires the full non open-source version of GATK.
     """
-    broad_runner, params, out_file = \
-        _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
-                               region, out_file)
-    assert broad_runner.gatk_type() == "restricted", \
-        "Require full version of GATK 2.4+ for haplotype calling"
+    if out_file is None:
+        out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     if not file_exists(out_file):
+        broad_runner, params = \
+            _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
+                                   region, out_file)
+        assert broad_runner.gatk_type() == "restricted", \
+            "Require full version of GATK 2.4+ for haplotype calling"
         if not all(has_aligned_reads(x, region) for x in align_bams):
             write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
                 params += ["-T", "HaplotypeCaller",
                            "-o", tx_out_file]
+                params = _gatk_location_hack(params)
                 broad_runner.run_gatk(params)
     return out_file
 
+def _gatk_location_hack(args):
+    """Temporary work around for issues in GATK 2.4-9 HaplotypeCaller.
+
+    Fixes:
+    - softclipped reads at end of chromosomes.
+      Pads these regions to avoid working exclusively with the end. Needs to be
+      fixed properly in upstream GATK.
+    - Problematic assembly around repeat regions. Excludes these regions.
+    """
+    region_idxs = [i + 1 for i, x in enumerate(args) if x == "-L"]
+    # padding
+    problem_chrs = ["GL000195.1"]
+    pad_start = 100
+    # exclusion
+    exclude_args = {"20": ["-XL", "20:33972777-33973070"]}
+    extra_args = []
+    for ridx in region_idxs:
+        if os.path.isfile(args[ridx]):
+            with open(args[ridx]) as in_handle:
+                chrom = in_handle.readline().split()[0]
+        else:
+            chrom = args[ridx].split(":")[0]
+        if chrom in problem_chrs and args[ridx].find(":") > 0:
+            chrom, rest = args[ridx].split(":")
+            start, end = rest.split("-")
+            new_start = max([pad_start, int(start)])
+            args[ridx] = "%s:%s-%s" % (chrom, new_start, end)
+        elif chrom in exclude_args:
+            extra_args.extend(exclude_args[chrom])
+    return args + extra_args
+
 def write_empty_vcf(out_file):
     with open(out_file, "w") as out_handle:
         out_handle.write("##fileformat=VCFv4.1\n"
@@ -137,13 +169,17 @@ def combine_variant_files(orig_files, out_file, ref_file, config,
                       "-R", ref_file,
                       "--out", tx_out_file]
             priority_order = []
-            for orig_file in orig_files:
-                name = os.path.splitext(os.path.basename(orig_file))[0]
+            for i, orig_file in enumerate(orig_files):
+                name = "v%s" % i
                 params.extend(["--variant:{name}".format(name=name), orig_file])
                 priority_order.append(name)
             params.extend(["--rod_priority_list", ",".join(priority_order)])
             if quiet_out:
                 params.extend(["--suppressCommandLineHeader", "--setKey", "null"])
+            variant_regions = config["algorithm"].get("variant_regions", None)
+            if variant_regions:
+                params += ["-L", bamprep.region_to_gatk(variant_regions),
+                           "--interval_set_rule", "INTERSECTION"]
             broad_runner.run_gatk(params)
     return out_file
 
@@ -204,17 +240,18 @@ def _shared_variant_filtration(filter_type, cov_interval, snp_file,
                                ref_file, vrn_files):
     """Share functionality for filtering variants.
     """
-    recal_file = "{base}.recal".format(base = os.path.splitext(snp_file)[0])
-    tranches_file = "{base}.tranches".format(base = os.path.splitext(snp_file)[0])
+    recal_file = "{base}.recal".format(base=os.path.splitext(snp_file)[0])
+    tranches_file = "{base}.tranches".format(base=os.path.splitext(snp_file)[0])
     params = ["-T", "VariantRecalibrator",
               "-R", ref_file,
               "--input", snp_file,
               "--mode", filter_type,
               "-an", "QD",
               "-an", "FS",
-              "-an", "HaplotypeScore",
               "-an", "ReadPosRankSum"]
     if filter_type in ["SNP", "BOTH"]:
+        # Haplotype Score no longer calculated for indels as of GATK 2.4
+        params.extend(["-an", "HaplotypeScore"])
         params.extend(
             ["-resource:hapmap,VCF,known=false,training=true,truth=true,prior=15.0",
              vrn_files.train_hapmap,
@@ -225,11 +262,10 @@ def _shared_variant_filtration(filter_type, cov_interval, snp_file,
               "-an", "MQRankSum",
               "-an", "MQ"])
     if filter_type in ["INDEL", "BOTH"]:
-        assert vrn_files.train_indels, \
-               "Need indel training file specified"
+        assert vrn_files.train_indels, "Need indel training file specified"
         params.extend(
             ["-resource:mills,VCF,known=true,training=true,truth=true,prior=12.0",
-             vrn_files.train_indels,])
+             vrn_files.train_indels])
     if cov_interval == "exome":
         params.extend(["--maxGaussians", "4", "--percentBadVariants", "0.05"])
     else:
@@ -284,7 +320,7 @@ def _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
                                            filters)
     else:
         # also check if we've failed recal and needed to do strict filtering
-        filter_file = "{base}-filterSNP.vcf".format(base = os.path.splitext(snp_file)[0])
+        filter_file = "{base}-filterSNP.vcf".format(base=os.path.splitext(snp_file)[0])
         if file_exists(filter_file):
             config["algorithm"]["coverage_interval"] = "regional"
             return _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
@@ -372,7 +408,7 @@ def _format_stats(stats):
         titv_novel = float(ti_novel) / float(tv_novel)
     else:
         titv_all, titv_dbsnp, titv_novel = (-1.0, -1.0, -1.0)
-    return dict(total=total, dbsnp_pct = dbsnp, titv_all=titv_all,
+    return dict(total=total, dbsnp_pct=dbsnp, titv_all=titv_all,
                 titv_dbsnp=titv_dbsnp, titv_novel=titv_novel)
 
 def _extract_eval_stats(eval_file):
@@ -380,7 +416,7 @@ def _extract_eval_stats(eval_file):
     """
     stats = dict()
     for snp_type in ['called', 'filtered']:
-        stats[snp_type]  = dict()
+        stats[snp_type] = dict()
         for dbsnp_type in ['known', 'novel']:
             stats[snp_type][dbsnp_type] = dict(ti=0, tv=0)
     for line in _eval_analysis_type(eval_file, "Ti/Tv Variant Evaluator"):
@@ -442,25 +478,6 @@ def variant_eval(vcf_in, ref_file, dbsnp, picard):
             picard.run_gatk(params)
     return out_file
 
-def _is_bed_file(fname):
-    """Simple check if a file is in BED format.
-    """
-    if fname.lower().endswith(".bed"):
-        return True
-    with open(fname) as in_handle:
-        for line in in_handle:
-            if not line.startswith("#"):
-                parts = line.split("\t")
-                if len(parts) > 3:
-                    try:
-                        int(parts[1])
-                        int(parts[2])
-                        return True
-                    except ValueError:
-                        pass
-                break
-    return False
-
 # ## High level functionality to run genotyping in parallel
 
 def get_variantcaller(data):
@@ -475,7 +492,8 @@ def combine_multiple_callers(data):
     out = []
     for grouped_calls in by_bam.itervalues():
         ready_calls = [{"variantcaller": get_variantcaller(x),
-                        "vrn_file": x.get("vrn_file")}
+                        "vrn_file": x.get("vrn_file"),
+                        "validate": x.get("validate")}
                        for x in grouped_calls]
         final = grouped_calls[0]
         def orig_variantcaller_order(x):
@@ -518,7 +536,7 @@ def parallel_variantcall(sample_info, parallel_fn):
             finished.append(x)
     if len(to_process) > 0:
         split_fn = process_bam_by_chromosome("-variants.vcf", "work_bam",
-                                             dir_ext_fn = get_variantcaller)
+                                             dir_ext_fn=get_variantcaller)
         processed = grouped_parallel_split_combine(
             to_process, split_fn, multi.group_batches, parallel_fn,
             "variantcall_sample", "split_variants_by_sample", "combine_variant_files",
